@@ -14,3 +14,7 @@ class URLNotAuthorizedNomadException(Exception):
     """The requested URL is not authorized. ACL"""
     def __init__(self, nomad_resp):
         self.nomad_resp = nomad_resp
+
+
+class InvalidParameters(Exception):
+    """Invalid parameters given"""
